package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````'C!````
M`````````$``.``-`$``'P`>``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````/@:````````^!H`````````
M$`````````$````%`````"``````````(``````````@````````74,`````
M``!=0P`````````0`````````0````0`````<`````````!P`````````'``
M``````!P1@```````'!&`````````!`````````!````!@```*B[````````
MJ,L```````"HRP```````(`$````````J`0`````````$`````````(````&
M````V+L```````#8RP```````-C+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````#`!````````,`$````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``"PL````````+"P````````L+`````````$`0````````0!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````J+L```````"HRP```````*C+````
M````6`0```````!8!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`\=3=_FVY;G.*/5G\
MD16++HNO3>P$````8````'X:_LI&1$\`>R)T>7!E(CHB9&5B(BPB;W,B.B)U
M8G5N='4B+")N86UE(CHB9VQI8F,B+")V97)S:6]N(CHB,BXT,"TQ=6)U;G1U
M,R(L(F%R8VAI=&5C='5R92(Z(F%M9#8T(GT`````!````&P```!^&O[*1D1/
M`'LB='EP92(Z(F1E8B(L(F]S(CHB=6)U;G1U(BPB;F%M92(Z(FQI8G!A<BUP
M86-K97(M<&5R;"(L(G9E<G-I;VXB.B(Q+C`V,RTQ8G5I;&0Q(BPB87)C:&ET
M96-T=7)E(CHB86UD-C0B?0````0````0`````0```$=.50```````P````(`
M````````$0```$,````$````"````"`0$``%0`2$*`(`!("&`(2"B0`""2`$
M"(B`$4&Z``((`````$,```!&````20```$H```!2````4P```%0`````````
M5@```%<```!8````60```%L```!=``````````````!NQ=\?SMY'+6M_FGPN
MQ9NVU&34?"'_Y`[9<5@<XD?&`;(!BV^L2^/`0OK7A\+E/RRZXY)\^J%L8)E/
MPYMK"4/69Z_,9D)%U>R)!W#3,V+;[16,)<P-.I<+?JF<F]%ESFW@IP(*:QJ>
M4*/@^TD```````````````````````````````"F`@``$@``````````````
M```````````-`@``$@````````````````````````",````$0``````````
M``````````````"-`@``$@`````````````````````````^`0``$@``````
M``````````````````#H`0``$@````````````````````````!)`@``$@``
M```````````````````````!````(`````````````````````````"X`0``
M$@````````````````````````!G````$@````````````````````````#%
M`0``$@````````````````````````"4````$@``````````````````````
M``"&`@``$@````````````````````````#8`@``$@``````````````````
M``````#]`0``$@````````````````````````#2````$@``````````````
M``````````#B````$@`````````````````````````P`0``$@``````````
M``````````````!Q`0``$@````````````````````````!J`0``$@``````
M``````````````````"*````$0````````````````````````""`P``$@``
M```````````````````````0````(`````````````````````````"^`@``
M$@````````````````````````"K`@``$@````````````````````````"]
M````$@`````````````````````````L````(```````````````````````
M``"=````$@````````````````````````"K````$@``````````````````
M``````"I`0``$@````````````````````````"P`@``$@``````````````
M``````````#H````%@````````````````````````#[````$@``````````
M``````````````!<`@``$@`````````````````````````6`0``$@``````
M``````````````````#)`@``$@````````````````````````":`0``$@``
M``````````````````````#V`0``$@````````````````````````!%`0``
M$@`````````````````````````G`0``$@````````````````````````!^
M`0``$@````````````````````````"8`@``$@``````````````````````
M``#7`0``$@````````````````````````"%`0``$@``````````````````
M```````N`@``$@````````````````````````!Y````$@``````````````
M``````````"3`0``$@````````````````````````",`0``$@``````````
M``````````````"<````$@````````````````````````#*`0``$@``````
M```````````````````9`@``$@````````````````````````!Z`@``$@``
M``````````````````````"]`0``$@````````````````````````#9````
M$@````````````````````````#$````$@````````````````````````"B
M`0``$0````````````````````````!M`@``$0``````````````````````
M``"D````$@````````````````````````!B`0``$@``````````````````
M```````+`0``$@````````````````````````!4`0``$@``````````````
M```````````Z`@``$@````````````````````````!&````$@``````````
M``````````````#A`@``$@````````````````````````"S````$@``````
M``````````````````#1`0``$@````````````````````````"+`P``$@`1
M`*!=````````UP````````#@`P``$@`1`*!3````````QP<```````!3````
M$@`1```G````````#@(````````"`P``$@`1`/!'````````"0`````````@
M`P``$@`1`'!;````````*`(````````&!```$@`1``!(````````$@(`````
M``#&`P``$``<`"C0```````````````````3`P``$@`1`"!*````````,@``
M```````V`P``$@`1`"!0````````:0````````"7`P``$0`3``!P````````
M!`````````"S`P``$@`1`-!>````````X`$```````"^`P``$@`1`.!&````
M````*0````````#;`P``$``<`%#0``````````````````#T`P``$@`1`,!2
M````````W@`````````=!```$@`1`)!0````````P`````````"F`P``$``;
M``#0``````````````````!:`P``$@`1`&!*````````40$```````#M`P``
M$``;`"C0```````````````````3!```$0`;`"#0````````"`````````"L
M`P``$@`1`!`I````````)@````````#2`P``$@`1`(!>````````1@``````
M``"H`P``(``;``#0``````````````````!P`P``$@`1`*!2````````'@``
M``````!8````(@````````````````````````!$`P``$@`1`!!'````````
MW0````````!F`P``$@`1`+!@````````@P(````````E!```$@`1`,!+````
M````6P0`````````7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES=&5R5$U#
M;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L:6)C7W-T
M87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O<FL`7U]S
M=&%C:U]C:&M?9F%I;`!?7V5N=FER;VX`<W1R;F-M<`!L<W1A=#8T`&%C8V5S
M<P!O<&5N9&ER`')E861D:7(V-`!S=')L96X`7U]S<')I;G1F7V-H:P!U;FQI
M;FL`8VQO<V5D:7(`<FUD:7(`4$Q?8W5R<F5N=%]C;VYT97AT`&)O;W1?1'EN
M84QO861E<@!097)L7VYE=UA3`%!E<FQ?;F5W6%-?9FQA9W,`<F5A9&QI;FL`
M4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]M96UM;W9E
M7V-H:P!R96%L;&]C`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR`'-T<F1U
M<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`<W1D97)R`%]?=F9P<FEN=&9?8VAK
M`&5X:70`;'-E96LV-`!R96%D`&=E='5I9`!M:V1I<@!?7V5R<FYO7VQO8V%T
M:6]N`%]?9G!R:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C
M:P!03%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`
M<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L
M;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?<G5N`&UE;6-P>0!L:6)P97)L+G-O
M+C4N-#``;&EB8RYS;RXV`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE
M`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A<E]C=7)R
M96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`
M7U]D871A7W-T87)T`'-H85]U<&1A=&4`>'-?:6YI=`!?7V)S<U]S=&%R=`!S
M:&%?:6YI=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N
M,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4``````0`!
M``(``0`"``,``0`!``(`!``"``(``@`!``$``@`"``$``P`"``(``@`!``$`
M`@`"``$`!0`"``,``0`!``$``0`!``$``@`"``$``@`"``$``@`"``$`!@`"
M``(`!0`"``$``0`"``(``P`"``$``@`"``$``P`!``<`"``"``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``(``0`!
M``$````!``<`^`(``!``````````E)&6!@``"``R!```$````+21E@8```<`
M/00``!`````4:6D-```&`$@$```0````LY&6!@``!0!2!```$````'(9:0D`
M``0`700``!````!T&6D)```#`&D$```0````=1II"0```@!U!````````*C+
M````````"`````````#P*0```````+#+````````"`````````"P*0``````
M`+C+````````"`````````!.<0```````,#+````````"`````````#I<```
M`````,C+````````"``````````&<0```````-#+````````"`````````!?
M<0````````C0````````"``````````(T````````"#0````````"```````
M``#X<@```````*#/````````!@````,``````````````*C/````````!@``
M``<``````````````+#/````````!@````@``````````````+C/````````
M!@```!<``````````````,#/````````!@```!L``````````````,C/````
M````!@```%H``````````````-#/````````$@```"```````````````-C/
M````````!@```"$``````````````.#/````````!@```"(`````````````
M`.C/````````!@```#@``````````````/#/````````!@```#D`````````
M`````/C/````````!@```#\``````````````/#-````````!P````$`````
M`````````/C-````````!P````(```````````````#.````````!P````0`
M``````````````C.````````!P````4``````````````!#.````````!P``
M``8``````````````!C.````````!P````D``````````````"#.````````
M!P````H``````````````"C.````````!P````L``````````````##.````
M````!P````P``````````````#C.````````!P````T``````````````$#.
M````````!P````X``````````````$C.````````!P````\`````````````
M`%#.````````!P```!```````````````%C.````````!P```!$`````````
M`````&#.````````!P```!(``````````````&C.````````!P```!,`````
M`````````'#.````````!P```!0``````````````'C.````````!P```!8`
M`````````````(#.````````!P```!@``````````````(C.````````!P``
M`!D``````````````)#.````````!P```!H``````````````)C.````````
M!P```!P``````````````*#.````````!P```!T``````````````*C.````
M````!P```!X``````````````+#.````````!P```!\``````````````+C.
M````````!P```",``````````````,#.````````!P```"0`````````````
M`,C.````````!P```"4``````````````-#.````````!P```"8`````````
M`````-C.````````!P```"<``````````````.#.````````!P```"@`````
M`````````.C.````````!P```"D``````````````/#.````````!P```"H`
M`````````````/C.````````!P```"L```````````````#/````````!P``
M`"P```````````````C/````````!P```"T``````````````!#/````````
M!P```"X``````````````!C/````````!P```"\``````````````"#/````
M````!P```#```````````````"C/````````!P```#$``````````````##/
M````````!P```#(``````````````#C/````````!P```#,`````````````
M`$#/````````!P```#0``````````````$C/````````!P```#4`````````
M`````%#/````````!P```#8``````````````%C/````````!P```#<`````
M`````````&#/````````!P```#H``````````````&C/````````!P```#L`
M`````````````'#/````````!P```#P``````````````'C/````````!P``
M`#T``````````````(#/````````!P```#X``````````````(C/````````
M!P```$```````````````)#/````````!P```$$``````````````)C/````
M````!P```$(`````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\UNJT``/\EO*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z_R4NK```9@\?1```\P\>^O\E1JH``&8/'T0`
M`/,/'OK_)3ZJ``!F#Q]$``#S#Q[Z_R4VJ@``9@\?1```\P\>^O\E+JH``&8/
M'T0``/,/'OK_)2:J``!F#Q]$``#S#Q[Z_R4>J@``9@\?1```\P\>^O\E%JH`
M`&8/'T0``/,/'OK_)0ZJ``!F#Q]$``#S#Q[Z_R4&J@``9@\?1```\P\>^O\E
M_JD``&8/'T0``/,/'OK_)?:I``!F#Q]$``#S#Q[Z_R7NJ0``9@\?1```\P\>
M^O\EYJD``&8/'T0``/,/'OK_)=ZI``!F#Q]$``#S#Q[Z_R76J0``9@\?1```
M\P\>^O\ESJD``&8/'T0``/,/'OK_)<:I``!F#Q]$``#S#Q[Z_R6^J0``9@\?
M1```\P\>^O\EMJD``&8/'T0``/,/'OK_):ZI``!F#Q]$``#S#Q[Z_R6FJ0``
M9@\?1```\P\>^O\EGJD``&8/'T0``/,/'OK_)9:I``!F#Q]$``#S#Q[Z_R6.
MJ0``9@\?1```\P\>^O\EAJD``&8/'T0``/,/'OK_)7ZI``!F#Q]$``#S#Q[Z
M_R5VJ0``9@\?1```\P\>^O\E;JD``&8/'T0``/,/'OK_)6:I``!F#Q]$``#S
M#Q[Z_R5>J0``9@\?1```\P\>^O\E5JD``&8/'T0``/,/'OK_)4ZI``!F#Q]$
M``#S#Q[Z_R5&J0``9@\?1```\P\>^O\E/JD``&8/'T0``/,/'OK_)3:I``!F
M#Q]$``#S#Q[Z_R4NJ0``9@\?1```\P\>^O\E)JD``&8/'T0``/,/'OK_)1ZI
M``!F#Q]$``#S#Q[Z_R46J0``9@\?1```\P\>^O\E#JD``&8/'T0``/,/'OK_
M)0:I``!F#Q]$``#S#Q[Z_R7^J```9@\?1```\P\>^O\E]J@``&8/'T0``/,/
M'OK_)>ZH``!F#Q]$``#S#Q[Z_R7FJ```9@\?1```\P\>^O\EWJ@``&8/'T0`
M`/,/'OK_)=:H``!F#Q]$``#S#Q[Z_R7.J```9@\?1```\P\>^O\EQJ@``&8/
M'T0``/,/'OK_);ZH``!F#Q]$``#S#Q[Z_R6VJ```9@\?1```\P\>^O\EKJ@`
M`&8/'T0``/,/'OK_)::H``!F#Q]$``#S#Q[Z_R6>J```9@\?1```\P\>^E5(
MB>5!5%-(@^PPB7W<2(U]W$B)==!(C7702(E5R&1(BQ0E*````$B)5>A(C57(
MZ(C___](BS5IJ```2(L]FJ@``$B)\NCR.P``2(L%FZ@``(`X``^$'`$``$B+
M!6NH``!D2(L`@(@Z!````XM%W(UX!(U8`TAC_TC!YP/HN_[__TB+3=!$BT7<
M2(G&2(D%L:@``$B+`4B)!DB-!4-*``!(B48(2(T%<:@``$B+`$B)1A!(C04M
M2@``2(E&&$&#^`$/CBH!``!(@\$(08/``[@$````#Q^$``````!(BSE(8]"#
MP`%(@\$(2(D\UD0YP'7J2)A(BSTYJ```13'`2(GQ2,<$Q@````")VDB--0H;
M``#HI?O__X7`#X2'````2(L]#J@``$R-9>3H;?W__TR)YDB-/69(``")PS'`
MZ`H8``!(A<!T<$B+/>:G``#H2?O__^C$_/__2(M%Z&1(*P0E*`````^%F@``
M`$B#Q#")V%M!7%W#Z$'\__](B06RIP``2(G'2(7`=''HK?S__TB+!3:G``!D
M2(L0QH*V"````.F[_O__2(L]AZ<``.B*^___Z6C___](BSU^IP``2(7_=`KH
MU#0``.EZ____2(T]@$<``$R)YNAP%P``2(D%6:<``$B)QTB%P`^$6/___^O2
MN`0```#I]_[__[\!````Z.?Z___HTOS__V:0\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]X:8``$B-!=JF``!(
M.?AT%4B+!5ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]L:8``$B--:JF
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%):8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/6VF````=2M52(,]`J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@5%I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````54B)
MY4%7059(C8U`_?__3(V-P/W__T%505132('LF`(``&1(BQ0E*````$B)5<A(
MB?I(B<],C4(X#Q^``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)UDB)1_!,B=!(
MP>X@2,'H*$G!ZC@E`/\``$P)T$F)\DC!Y@A)P>(8@>8``/\`18G23`G02`GP
M2(E'^$PYSW6MN_____]F#V^%4/W__V8/;YU@_?__2(V%J/W__V9(#V[K9@]O
ME7#]__](@<%H`@``9@]L[68/'X0``````/,/;PAF#V_B9@]O4-A(@\`09@_O
M0(AF#^_*9@_OP68/;\AF#W/P`68/<]$?9@_KP68/V\4/*4`(9@]OPV8/;]Q(
M.<AUNTR+"DR+6A!(BWH@2(M:&$R)R$R)R4R+A4C]__](P>D;2,'@!4@)R`.%
M0/W__TZ-A`.9>8):C8PXF7F"6DR)V$@QV$@C0@A(,=B-/`%(BTH(2(M""$F)
M^DC!Z`)(P>$>2`G!3(G82<'J&XG.2#'P3"'(3#'83`'`28GX2<'@!4T)T$:-
M)`!,B<A-B<A)P>@"2,'@'DV)Y4P)P$R+A5#]__])P>T;2#'!08G"2"'Y3XV$
M`YEY@EI(,?%,`<%-B>!)P>`%30GH3(NM6/W__T$!R$B)^4C![P)(P>$>18G`
M2HVT+IEY@EI("?E-B<5(,<B)STPAX$G![1M,,=!(`?!,B<9(P>8%3`GN3(NM
M8/W__P'&3(G@2<'L`DC!X!Z)]D^-E"J9>8):3`G@28GU2#'!2<'M&T&)Q$PA
MP4@Q^4P!T4F)\DG!X@5-">I,BZUH_?__00'*3(G!2<'H`DC!X1Y%B=)*C;PO
MF7F"6DP)P4V)U4@QR$G![1M!B<A((?!,,>!(`?A,B==(P><%3`GO3(NM</W_
M_P''2(GP2,'N`DC!X!Z)_T^-I"R9>8):2`GP28G]2#'!2<'M&XG&3"'13#'!
M3`'A28G\2<'D!4T)[$R+K7C]__]!`<Q,B=%)P>H"2,'A'D6)Y$^-A"B9>8):
M3`G138GE2#'(2<'M&T&)RD@A^$@Q\$P!P$V)X$G!X`5-">A,BZV`_?__00'`
M2(GX2,'O`DC!X!Y%B<!*C;0NF7F"6D@)^$V)Q4@QP4G![1N)QTPAX4PQT4@!
M\4R)QDC!Y@5,">Y,BZV(_?__`<Y,B>%)P>P"2,'A'HGV3XV4*IEY@EI,">%)
MB?5(,<A)P>T;08G,3"'`2#'X3`'028GR2<'B!4T)ZDR+K9#]__]!`<),B<!)
MP>@"2,'@'D6)TDJ-O"^9>8):3`G`38G52#'!2<'M&T&)P$@A\4PQX4@!^4R)
MUTC!YP5,">],BZV8_?__`<](B?%(P>X"2,'A'HG_3XVD+)EY@EI("?%)B?U(
M,<A)P>T;B<Y,(=!,,<!,`>!)B?Q)P>0%30GL3(NMH/W__T$!Q$R)T$C!X!Y)
MP>H"18GD3XV$*)EY@EI,"=!-B>5(,<%)P>T;08G"2"'Y2#'Q3`'!38G@2<'@
M!4T)Z$R+K:C]__]!`<A(B?E(P>\"2,'A'D6)P$J-M"Z9>8):2`GY38G%2#'(
M2<'M&XG/3"'@3#'02`'P3(G&2,'F!4P)[DR+K;#]__\!QDR)X$G![`)(P>`>
MB?9/C90JF7F"6DP)X$F)]4@QP4G![1M!B<1,(<%(,?E,`=%)B?))P>(%30GJ
M3(NMN/W__T$!RDR)P4C!X1Y)P>@"18G22HV\+YEY@EI,"<%-B=5(,<A)P>T;
M08G(2"'P3#'@2`'X3(G72,'G!4P)[TR+K<#]__\!QTB)\$C![@)(P>`>B?]/
MC:0LF7F"6D@)\$F)_4@QP4G![1N)QDPAT4PQP4P!X4F)_$G!Y`5-">Q&C30A
M3(G12<'J`DC!X1Y,"=%,BY7(_?__2#'(08G,2"'X3XV$$)EY@EI-B?)(,?!)
MP>H;3`'`38GP2<'@!4T)T$R+E=#]__]!`<!(B?A(P>`>2,'O`D6)P$J-M!:9
M>8):2`GX38G"2#'!2<'J&XG'3"'Q3#'A2`'.3(G!2,'A!4P)T4V)\DG![@))
MP>(>B<E-"?)(`<Y(BXW8_?__3#'008GU3"'`28V,#)EY@EI-B>Q(,?A)P>P;
M2`'(3(GI2,'A!4P)X8G)2`'(3(G!2<'H`DC!X1Y!B<1,"<%-B=!%B=)),<A$
M,<9,BX7@_?__2HV\!Z'KV6Y-B>!(`?=,B>9)P>@;2,'F!4P)QHGV2`'W3(GN
M2,'F'DG![0)!B?A,`Y7H_?__3`GN28G-B<E(`XWP_?__23'U1#'H38G%38V4
M`J'KV6Y,B<!)P>T;2,'@!4P)Z(G`20'"3(G@2<'L`DC!X!Y%B=5,">!)B?2)
M]D@#M?C]__]),<1$,>=-B>Q(C;PYH>O9;DR)Z4G![!M(P>$%3`GAB<E(`<],
MB<%)P>@"2,'A'D&)_$P)P4F)P(G`23'(13'038GB3HV$!J'KV6Y,B>9)P>H;
M2,'F!4P)UHGV20'P3(GN2<'M`DC!YAY%B<),">Y)B<U(`X4`_O__B<E),?5(
M`XT(_O__1#'O38G52(V\.*'KV6Y,B=!)P>T;2,'@!4P)Z(G`2`''3(G@2<'L
M`DC!X!Y!B?U,">!)B?2)]D@#M1#^__]),<1%,>!-B>Q.C80!H>O9;DR)Z4G!
M[!M(P>$%3`GAB<E)`<A,B=%)P>H"2,'A'D6)Q$P)T4F)PHG`2`.%&/[__TDQ
MRD0QUTV)XDB-O#ZAZ]EN3(GF2<'J&TC!Y@5,"=:)]D@!]TR)[DG![0)(P>8>
M08GZ3`GN28G-B<E),?5(`XT@_O__13'H38G53HV$`*'KV6Y,B=!)P>T;2,'@
M!4P)Z(G`20'`3(G@2<'L`DC!X!Y%B<5,">!)B?2)]D@#M2C^__]),<1$,>=-
MB>Q(C;PYH>O9;DR)Z4G![!M(P>$%3`GAB<E(`<],B=%)P>H"2,'A'D&)_$P)
MT4F)PHG`2`.%,/[__TDQRD4QT$V)XDZ-A`:AZ]EN3(GF2<'J&TC!Y@5,"=:)
M]DD!\$R)[DG![0)(P>8>18G"3`GN28G-B<E),?5$,>]-B=5(C;PXH>O9;DR)
MT$C!X`5)P>T;2`.-./[__TP)Z(G`2`''3(G@2<'L`DC!X!Y!B?U,">!)B?2)
M]D@#M4#^__]),<1%,>!-B>Q.C80!H>O9;DR)Z4G![!M(P>$%3`GAB<E)`<A,
MB=%)P>H"2,'A'D6)Q$P)T4F)PHG`2`.%2/[__TDQRD0QUTV)XDB-O#ZAZ]EN
M3(GF2<'J&TC!Y@5,"=:)]D@!]TR)[DG![0)(P>8>08GZ3`GN28G-B<E),?5%
M,>A-B=5.C80`H>O9;DR)T$G![1M(P>`%3`GH2`.-4/[__XG`20'`3(G@2<'L
M`DC!X!Y%B<5,">!)B?2)]D@#M5C^__]),<1$,>=-B>Q(C;PYH>O9;DR)Z4G!
M[!M(P>$%3`GAB<E(`<],B=%)P>H"2,'A'D&)_$P)T4F)PHG`2`.%8/[__TDQ
MRD4QT$V)XDZ-A`:AZ]EN3(GF2<'J&TC!Y@5,"=:)]DD!\$R)[DG![0)(P>8>
M18G"3`GN28G-B<E),?5$,>]-B=5(C;PXH>O9;DR)T$G![1M(P>`%3`GHB<!(
M`<=,B>!(P>`>2<'L`D&)_4@#C6C^__],">!)B?2)]D@#M7#^__]),<1%,>!.
MC:0!H>O9;DR)Z4V)Z$G!Z!M(P>$%3`G!B<E)`<Q,B=%)P>H"2,'A'D6)X$P)
MT4F)PHG`2`.%>/[__TDQRD0QUTV)PDB-O#ZAZ]EN3(G&2<'J&TC!Y@5,"=9-
MB>I)P>T"2<'B'@'W2(G.B<E-">J)_TPQUDV)UD6)U40QYDF)_$B-M#"AZ]EN
M2(GX2<'L&TC!X`5,">!$C20&3(G&2<'H`KC<O!N/2,'F'DP)QDD)]D&)\$TA
MPDDA_DT)UDR+E8#^__])`<),`=%-B>),`?%-B>9)P>(%2<'N&TT)\D$!RDB)
M^4C![P)(P>$>18G22`GY2`G.28G.B<],(>9-(<9)"?9(B[6(_O__2`'&3`'N
M38G53`'V38G62<'E!4G![AM-"?5)B<Y!`?5,B>9)P>P"2,'F'D6)[4P)YD&)
M]$D)]DTAUDPAX4P)\4R+M9#^__])`<9-`<9-B>A,`?%-B>Y)P>`%2<'N&TT)
M\$$!R$R)T4G!Z@)(P>$>18G`3`G12`G.28G.08G*3"'N32'F20GV2(NUF/[_
M_T@!QD@!_DR)QTP!]DV)QDC!YP5)P>X;3`GW28G.`?=,B>Y)P>T"2,'F'HG_
M3`GN08GU20GV32'&3"'I3`GQ3(NUH/[__TD!QDT!YDF)_$P!\4F)_DG!Y`5)
MP>X;30GT00',3(G!2<'H`DC!X1Y%B>1,"<%("<Y)B<Y!B<A((?Y-(>Y)"?9(
MB[6H_O__2`'&3`'638GB3`'V38GF2<'B!4G![AM-"?))B<Y!`?)(B?Y(P>\"
M2,'F'D6)TD@)_HGW20GV32'F2"'Y3`GQ3(NUL/[__TD!QDT![DV)U4P!\4V)
MUDG!Y05)P>X;30GU00'-3(GA2,'A'DG![`)%B>U,">%("<Y)B<Y!B<Q,(=9)
M(?Y)"?9(B[6X_O__2`'&3`'&38GH3`'V38GN2<'@!4G![AM-"?!)B<Y!`?!,
MB=9)P>H"2,'F'D6)P$P)UD&)\DD)]DTA[DPAT4P)\4R+M<#^__])`<9)`?Y,
MB<=,`?%-B<9(P><%2<'N&TP)]P'/3(GI2<'M`DC!X1Z)_TP)Z4@)SDF)SD&)
MS4PAQDTAUDD)]DB+M<C^__](`<9,`>9)B?Q,`?9)B?Y)P>0%2<'N&TT)]$F)
MSD$!]$R)QDG!Z`)(P>8>18GD3`G&08GP20GV22'^3"'!3`GQ3(NUT/[__TD!
MQDT!UDV)XDP!\4V)YDG!X@5)P>X;30GR00'*2(GY2,'O`DC!X1Y%B=)("?E(
M"<Y)B<Z)STPAYDTAQDD)]DB+M=C^__](`<9,`>Y-B=5,`?9-B=9)P>4%2<'N
M&TT)]4F)SD$!]4R)YDG![`)(P>8>18GM3`GF08GT20GV32'63"'A3`GQ3(NU
MX/[__TD!QDT!QDV)Z$P!\4V)[DG!X`5)P>X;30GP00'(3(G12<'J`DC!X1Y%
MB<!,"=%("<Y)B<Y!B<I,(>Y-(>9)"?9(B[7H_O__2`'&2`'^3(G'3`'V38G&
M2,'G!4G![AM,"?=)B<X!]TR)[DG![0)(P>8>B?],">Y!B?5)"?9-(<9,(>E,
M"?%,B[7P_O__20'&30'F28G\3`'Q28G^2<'D!4G![AM-"?1!`<Q,B<%)P>@"
M2,'A'D6)Y$P)P4@)SDF)SD&)R$@A_DTA[DD)]DB+M?C^__](`<9,`=9-B>),
M`?9-B>9)P>(%2<'N&TT)\DF)SD$!\DB)_DC![P)(P>8>18G22`G^20GVB?=-
M(>9((?E,"?%,B[4`____20'&30'N38G53`'Q38G62<'E!4G![AM-"?5!`<U,
MB>%)P>P"2,'A'D6)[4P)X4@)SDF)S$&)STPAUDDA_$D)]$B+M0C___](`<9,
M`<9-B>A,`>9-B>Q)P>`%2<'L&TT)X$$!\$R)UDG!Z@)(P>8>18G`3`G628G*
M08GT20GR32'J3"'A3`G13(N5$/___TD!PD@#A1C___],`==-B<),`?A,B[TX
M____2`'/3(G!2<'J&TC!X05,"=&)R4@!STR)Z4G![0)(P>$>08GZ3`GI2`G.
M28G-08G.3"'&32'E20GU28UT!0!,B=!-B=5)P>T;2,'@!4P)Z(G`2`'&3(G`
M2<'H`DC!X!Y!B?5)"<"XUL%BRDPQP3'Y2(N](/___T@!QTP!YTV)[$@!^4R)
M[TG![!M(P><%3`GG38G4B?](`?E)P>0>20''2<'J`HG/30GB38G$18G`33'4
M03'T2(NU*/___T@!QDP!]DF)_DP!YDF)_$G![AM)P>0%30GT38GN2<'M`DG!
MYAY%B>1-"?5,B[4P____3`'F08GT20'&30'P38G633'N03'.3(GA30'P38GF
M2,'A!4G![AM,"?&)R4D!R$B)^4C![P)(P>$>18G&2`G/1(G138GJ23'Z3`'Y
M3(N]0/___T$Q\DJ--!%,B?%-B?)(P>$%2<'J&TD!QTP)T8G)2`'.3(GA2<'L
M`DC!X1Y!B?),">%%B>Q)B?V)_TDQS4T!_$R+O5C___]%,<5/C00L38G438G5
M2<'M&TG!Y`5-">Q-B?5)P>X"2<'E'D6)Y$T)[DR+K4C___]-`>!%B<1)`<5,
M`>])B<V)R4TQ]4$Q]4R)YDP![TV)Y4C!Y@5)P>T;3`GNB?9(`?=,B=9)P>H"
M2,'F'D&)_4P)UDR+E5#___])`<),`=%-B?)),?)%,<))`<=.C0013(GI38GJ
M2<'J&TC!X05,"=&)R4D!R$R)X4G![`)(P>$>18G"20G,1(GQ28GVB?9-,>9,
M`?E,B[UH____03'^2HT\,4R)T4V)UDD!QTG![AM(P>$%3`GQB<E(`<],B>E)
MP>T"2,'A'D&)_DP)Z4R+K6#___])`<5,`>Y-B>5),<U%,<5.C00N3(GV38GU
M2<'M&TC!Y@5,">Z)]DD!\$R)UDG!Z@)(P>8>18G%20GR1(GF28G,B<E,`?Y-
M,=1,B[UX____03'\2HT\)DR)[DV)[$D!QTG![!M(P>8%3`GFB?9(`?=,B?9)
MP>X"2,'F'D&)_$P)]DR+M7#___])`<9,`?%-B=9),?9%,<9.C00Q3(GA38GF
M2<'N&TC!X05,"?&)R4D!R$R)Z4G![0)(P>$>18G&20G-1(G128GRB?9-,>I,
M`?E,BWV(03'Z2HT\$4R)\4V)\DG!ZAM(P>$%3`G1B<E(`<],B>%)P>P"2,'A
M'D&)^DP)X4R+98!)`<1,`>9-B>Q)`<=),<Q%,<1.C00F3(G638G42<'L&TC!
MY@5,">:)]DD!\$R)]DG![@)(P>8>18G$20GV1(GN28G-B<E-,?5,`?Y,BWV8
M03']2HT\+DR)YDV)Y4G![1M(P>8%3`GNB?9(`?=,B=9)P>H"2,'F'D&)_4P)
MUDR+59!)`<),`=%-B?)),?)%,<).C0013(GI38GJ2<'J&TC!X05,"=&)R4D!
MR$R)X4G![`)(P>$>18G"20G,1(GQ28GV20''33'F3`'YB?9,BWVH03'^3(G7
M20'.3(G12,'O&TD!QTC!X05("?F)R4D!SDR)Z4G![0)(P>$>1(GW3`GI3(MM
MH$D!Q4P![DV)Y4DQS44QQ4Z-!"Y(B?Y)B?U)P>T;2,'F!4P)[HGV20'P3(G6
M2<'J`DC!YAY%B<5)"?)$B>9)B<R)R4TQU$P!_D4Q]$V)[DP!YDV)[$G![AM)
MP>0%30GT28G^18GD3`'F2<'F'DC![P)!B?1,"?=,BW6P20'&2`-%N$P!\4V)
MUDP!R$6)TDDQ_DP!T$4QQDV)X$P!\4V)YDG!X`5)P>X;30GP1`'!38GH2<'M
M`DG!X!Z)R4T)Q4F)^`-Z($TQZ$$!W4B)>B!$,<9)B<A,B6H82`'P2(G.2<'H
M&P-*"$C!Y@5(B4H(3`G&`?!(B0),B>!)P>P"2,'@'DP)X$0!V$B)0A!(BT7(
M9$@K!"4H````=1)(@<28`@``6T%<05U!7D%?7</HE>7__P\?1```54B)Y4%7
M059!54%44TB#[!A(BP4XCP``2(EUR$R+,$V%]@^$GP````^V!TF)_83`=`0\
M/75:13'D28L>2(7;=#5-8^1-B?=F#Q^$``````!,B>),B>Y(B=_H<N/__X7`
M=0="@#PC/71'28M?"$F#QPA(A=MUVDB#Q!A(B=A;05Q!74%>05]=PP\?A```
M````28G\00^V1"0!28/$`83`=`0\/77N12GLZX]F#Q]$``!,B?E(BT7(2HU<
M(P%,*?%(P?D#B0CKKS';ZZL/'T0``%5(B>532(VU4/___TB![*@```!D2(L<
M)2@```!(B5WH2(G[Z,CD__^%P'4TBY5H____@>(`\```@?H`0```=`B!^@"@
M``!U&KX"````2(G?Z`OE__^%P`^4P`^VP.L#D#'`2(M5Z&1(*Q0E*````'4&
M2(M=^,G#Z$3D__\/'T``54B)Y4%7059!54%44TB![*@```!D2(L$)2@```!(
MB47(,<!(A?]T"(`_`$B)^W4H2(M%R&1(*P0E*`````^%+`$``$B!Q*@```!;
M05Q!74%>05]=PP\?`.@#X___28G%2(7`=,M,B>_HT^3__TB%P`^$N@```(!X
M$RY,C6`3=1!!@'PD`0!TW0\?A```````@'@3+@^$K@```$B)W^B>XO__3(GG
M28G&Z)/B__]%C7P&`DUC_TR)_^C3X?__38GA28G83(GZ28G&2(G'O@(````Q
MP$B-#8HM``#H\>/__TR)]TB-M3#____H8N+__TR)]X/X_W02BX5(____)0#P
M```]`$```'1@Z+/A__],B??H&^+__TR)[^@CY/__2(7`#X50____9BX/'X0`
M`````$R)[^B(X___2(G?Z)#A___IZ_[__P\?`$&`?"0!+@^%1O___T&`?"0"
M``^$!?___^DU____#Q\`Z)/^___KGNC,XO__9F8N#Q^$``````"0\P\>^E5(
MC0U$;0``2(TUURP``$B)Y5-(@^P(2(L=CHP``$B+%8^,``!D2(L[Z$[C__]D
M2(L[2(M=^$4QR4B-%0P8``!,C059+@``2(TUM"P``,E,B<'IM>'__P\?1```
M54B)Y4%6055!5%-(@>P`$```2(,,)`!(@^P0NO\/``!D3(LD)2@```!,B678
M28GT3(VMT.___TB)^TB-/7HL``!,B>[HM^'__X7`?A:)P8/H`4ACT("\%=#O
M__\`=4&%P'4U2(L%YHL``$R)XDB)WF1(BSCHA^#__TB+1=AD2"L$)2@```!U
M2TB!Q!`0``!;05Q!74%>7<.)P68/'T0``$QC\;XO````3(GO3(GRZ)W?__](
MA<!TJTB+!9&+``!,B?%,B>I(B=YD2(LXZ!_A___KINB(X?__#Q^$``````!5
M,<!(B>5!5T%6055!5%-(B?M(@^PH@#X]9$R++"4H````3(EMR$F)]0^4P$D!
MQ4R)[^A)X/__2(UUQ$B)WTF)Q#'`Z*C[__](A<`/A"<!``!(B<=)B<;H).#_
M_TPYX`^#\P```$QC1<1,BSW0B@``2<'@`P^V`X3`#X39`0``/#T/A-$!``!(
MB=AF9BX/'X0``````&9F+@\?A```````#[90`4B#P`&$TG0%@/H]=>](*=A(
MF$J-?"`"38G&3(E%N$T#-^@&W___28D&2(7`=&!)BP=,BT6X2(U+`4J+%``/
MM@.(`CP]="N$P'46ZR5F9BX/'X0```````\?1```/#UT$0^V`4B#P@%(@\$!
MB`*$P'7KQ@(],<!F#Q]$``!!#[9,!0"(3`(!2(/``83)=>Y(BT7(9$@K!"4H
M````#X4G`0``2(/$*%M!7$%=05Y!7UW##Q]``#'`9@\?1```00^V5`4`08@4
M!DB#P`&$TG7NZ[X/'T``3(L]P8D``$V+#TF#.0`/A-,```!,B<A%,?9F9BX/
M'X0```````\?`$B#P`A$B?)!@\8!2(,X`'7OC4H#2&/)2,'A`XL%#XH``(7`
M=6M(B<],B4VPQP7ZB0```0```$B)3;CH\=W__TB)QTB%P`^$1____TUCQDB+
M3;A(BW6P2<'@`TR)PDR)1;CH2N#__TR+1;A)B0=(B<=!C48!1(EUQ$B82,<$
MQP````#I3?[__V8/'X0``````$R)STB)SNCUW___28D'2(G'2(7`#X3H_O__
M36/&2<'@`^N]#Q]$```QP.E7_O__N1````!%,?;I3____^@/W___9F8N#Q^$
M```````/'T``\P\>^DB+!>6(``!(BQ7FB```2(T-=VD``$B--0HI``!D2(LX
MZ9??__\/'X``````\P\>^E5(B>5!54%44TB![``0``!(@PPD`$B![``0``!(
M@PPD`$B#["AD2(L$)2@```!(B478,<!(C9W0[___3(VEP-___^A%W?__3(T-
MY"@``+H!$```2(G?08G`2(T-UB@``+X"````,<#H\-[__TB)W[H`$```3(GF
MZ/#=__\Q_X7`>#)$C6@!2(G#36/M3(GOZ(C<__](B<=(A<!T&$ACVTR)Z4R)
MYDB)VNC/W/__Q@08`$B)QTB+1=AD2"L$)2@```!U$4B!Q"@@``!(B?A;05Q!
M75W#Z//=__\/'P#S#Q[ZZ1?___\/'X``````\P\>^E5(B>5!5T%6055!5%-(
M@>P`$```2(,,)`!(@>RX````9$B+!"4H````2(E%R#'`28G\28GU2(T]&"@`
M`$B-M2SO___H!/C__[XO````3(GG2(G#Z#3=__](A<!T/S'`3(GF2(T]]"<`
M`.CN^___3(G@2(M5R&1(*Q0E*`````^%A0$``$B-9=A;05Q!74%>05]=PV8/
M'X0``````$R)[TR-+<0G``#H$=W__TR)[DB)Q^A&W?__28G&2(7`=)]!@#X`
M#X3B````#Q]``$B%VW033(GV2(G?Z!#=__^%P`^$I@```$R)]^CPV___28U4
M!O])B<=).=9R#^L=D,8"`$B#Z@%).=9T!8`Z+W3O3(GWZ,?;__])B<=,B>?H
MO-O__TF-1`<!2#W_#P``#X<L____2(/L"$R-O<#O__]-B?`QP$%4N@`0``"^
M`@```$R)_TB-#1DH``!,C0T.)P``Z`G=__](C;4P[___3(G_Z'K;__]:687`
M=1*+A4CO__\E`/```#T`@```=%),B>XQ_^AHW/__28G&2(7`#X2]_O__08`^
M``^%(O___TB%VW0%@#LN=!A!OP$```!,C361)@``Z5+___]F#Q]$``"`>P$`
M=+CKX`\?A```````O@$```!,B?_HD]S__X7`=9U,B?Y(C3UF)@``Z&#Z__],
MB?_HN-O__^EH_O__Z,[;__]F9BX/'X0```````\?`/,/'OI5OB\```!(B>53
M2(G[2(/L".@6V___2(U0`4B%P$@/1=I(B=](BUWXR>ENV___9F8N#Q^$````
M```/'P#S#Q[Z54B)Y4%44TB![``0``!(@PPD`$B#[!!D2(L$)2@```!(B47H
M,<!(A?\/A-T```"`/P!(B?L/A-$```#H/-K__TB)PDB-0`%(/0`0```/A_$`
M``!,C:7@[___3(GG@_@(<@Z)P4B)WL'I`_-(I4B)\S')J`1T"8L+B0^Y!```
M`*@"=`Y$#[<$"V9$B00/2(/!`J@!=`</M@0+B`0/28U$%/]).<1R(NLE9F8N
M#Q^$``````!F#Q^$``````#&``!(@^@!3#G@=`6`."]T[[XO````3(GGZ!+:
M__](A<!T+4DYQ')83(GGZ'#:__](BU7H9$@K%"4H````=4U(@<00$```6T%<
M7<,/'T0``$B+1>AD2"L$)2@```!U+4B!Q!`0``!(C3W))```6T%<7>DJVO__
M9BX/'X0``````,8``.NC#Q\`,<#KI.@OVO__9F8N#Q^$```````/'T``\P\>
M^E5(B>5!5T%6055!5$R-)9LD``!32(/L&&1(BQPE*````$B)7<A(C5W$#Q\`
M,<!(B=Y,B>?H4_3__TB%P'0V2(L%EX,``$AC5<1(BP!(C0302(M0"$B)$$B%
MTG302(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE/"0``)`QP$B)WDR)Y^@#
M]/__2(7`=#9(BP5'@P``2&-5Q$B+`$B-!-!(BU`(2(D02(72=-!(BU`02(/`
M"$B)$$B%TG7PZ[YF#Q]$``!,C27T(P``D#'`2(G>3(GGZ+/S__](A<!T-DB+
M!?>"``!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TT$B+4!!(@\`(2(D02(72=?#K
MOF8/'T0``$R-):TC``"0,<!(B=Y,B>?H8_/__TB%P'0V2(L%IX(``$AC5<1(
MBP!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE
M9",``)`QP$B)WDR)Y^@3\___2(7`=#9(BP57@@``2&-5Q$B+`$B-!-!(BU`(
M2(D02(72=-!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C2TD(P``D#'`2(G>
M3(GOZ,/R__](A<!T-DB+!0>"``!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TT$B+
M4!!(@\`(2(D02(72=?#KOF8/'T0``$R-+8DB``"0,<!(B=Y,B>_H<_+__TB%
MP'0V2(L%MX$``$AC5<1(BP!(C0302(M0"$B)$$B%TG302(M0$$B#P`A(B1!(
MA=)U\.N^9@\?1```3(T]D"(``)`QP$B)WDR)_^@C\O__2(7`=#9(BP5G@0``
M2&-5Q$B+`$B-!-!(BU`(2(D02(72=-!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$
M``!,C35*(@``D#'`2(G>3(GWZ-/Q__](A<!T-DB+!1>!``!(8U7$2(L`2(T$
MT$B+4`A(B1!(A=)TT$B+4!!(@\`(2(D02(72=?#KOF8/'T0``#'`2(G>2(T]
M_R$``.B'\?__2(7`=#I(BP7+@```2&-5Q$B+`$B-!-!(BU`(2(D02(72=,P/
M'T``2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```,<!(B=Y(C3U-(0``Z#?Q__](
MA<!T.DB+!7N```!(8U7$2(L`2(T$T$B+4`A(B1!(A=)TS`\?0`!(BU`02(/`
M"$B)$$B%TG7PZ[9F#Q]$``!(B=Y(C3UK(0``Z.GP__](A<!T#4B)QDR)]S'`
MZ.?T__\QP$B)WDB-/5DA``#HQO#__TB%P'012(G&2(T]5R$``#'`Z,#T__](
MB=Y(C3U1(0``,<#HG_#__TB)QDB%P'0X3(GO,<#HG?3__TB+1<AD2"L$)2@`
M``!U1$B#Q!A,B>=(C34\(0``,<!;05Q!74%>05]=Z6_T__\QP$B)WDB-/0XA
M``#H3O#__TB%P'2\2(G&3(G_,<#H3/3__^NMZ,75__\/'T0``/,/'OI52(T]
M@R```$B)Y4B#[!!D2(L$)2@```!(B47X,<!(C77TZ`7P__](A<!T,`^V$(#Z
M,`^4P(32#Y3""="#\`$/ML!(BU7X9$@K%"4H````=0_)PV8/'X0``````#'`
MZ^+H5]7__P\?@`````#S#Q[Z54B)Y4B![-````!(B;58____2(F58/___TB)
MC6C___],B85P____3(F->/___X3`="`/*46`#RE-D`\I5:`/*5VP#REEP`\I
M;=`/*77@#RE]\&1(BP0E*````$B)A4C___\QP$B-11!(B?I(C8TP____2(F%
M./___[X"````2(V%4/___TB)A4#___](BP7!?@``QX4P____"````,>%-/__
M_S````!(BP!(B<?HRM/__[__````Z*#2__]52(GE055!5%-,C9PD``#__TB!
M[``0``!(@PPD`$PYW'7O2(/L&+H"````,?9D3(LL)2@```!,B6W808G]2(V=
MT/_^_^BWU/__3(U@_TR)XDC!^C](P>HP28T$%`^WP$@IT$DIQ`^(L0````\?
M1```,=),B>9$B>_H@]3__TB#^/\/A*P```"Z"``!`$B)WD2)[^@ITO__@_C_
M#X2%````2)A(@_@'=F!(C40#^$@YV')62(T5!WX``.L>9F8N#Q^$``````!F
M+@\?A```````2(/H`4@YV'(O2(L(2#D*=>](*=A,`>!(BU789$@K%"4H````
M=4M(@<08``$`6T%<05U=PP\?0`!)@>P```$`28'\``#__P^%5/___TC'P/__
M___KPDB-/:\>```QP.@-_O__2(T]E!X``#'`Z/_]___H2M/__V8N#Q^$````
M``#S#Q[Z54B)Y>AST___B<?H_-'__TB%P'0#2(L`7<-FD/,/'OI52(GE05=!
M5DB-=<1!54R-+5X>``!!5$F)_$R)[U-(@^P89$B+!"4H````2(E%R#'`Z%;M
M__](A<!T"(`X`$B)PW4Q2(M%R&1(*P0E*`````^%?P```$R)YDB-9=A,B>\Q
MP%M!7$%=05Y!7UWI*_'__P\?`$R)Y^B@T?__2(G?28G&Z)71__]-C7P&`DR)
M_^C8T/__2(/L"$R)^DV)X%-(B<=)B<9,C0W^'```2(T-_1T``+X"````,<#H
M[=+__UA:2(M%R&1(*P0E*````'4%3(GVZX3H0M+__V:0\P\>^E5(B>5!5T%6
M3(V]M/[__T%53(G^05132('L2`$``$B)O:C^___S#WX%YW<``$B-/8`<``!D
M2(L$)2@```!(B47(2(T%:AP``$C'A?#^__\`````2,>%*/___P````!(QX70
M_O__`````&9(#V[(2(T%.AT``&8/;,%F2`]NT$B-!3(=```/*87@_O__9D@/
M;MCS#WX%@W<``$B-!2`=``!F2`]NX#'`9@]LP@\1A0C____S#WX%:G<``&8/
M;,,/$848____\P]^!5]W``!F#VS$#RF%P/[__^C/Z___2(7`=`R`.`!(B<,/
MA08%``#HB='__XG'Z!+0__](A<`/A#D$``!,BS!-A?8/A"T$``!,B??H)=#_
M_TR-;``!3(GO3(GKZ&7/__]%#[8&2(F%H/[__TF)Q$6$P'139I!,B>I%#[;`
M3(GG,<!(C0UZ'```O@(```!)@\8!Z&_1__],.>M,B>I%#[8&2`]#TTB)T$PI
MZ$B#P`)(.=!(#T+"22G528/$`DV-;`7^183`=:],C:T`____2(T]L1L``.L4
M#Q^``````$F+?0A)@\4(2(7_=#M,B?XQP.CQZO__28G$2(7`=.&`.`!TW$B)
MQ^BLZ___A<!TT$R)Y^A`T/__28G$2(7`=4`/'X0``````$R-K>#^__]-BV4`
M387D="A!@#PD``^$)0,``$R)Y^AMZ___A<`/A0T!``!-BV4(28/%"$V%Y'78
M3(GGZ!#/__](BYV@_O__28G%2(G?Z/[.__]%C;0%!`0``$UC]DR)]^@[SO__
M4TV)X$R-#7`:``!)B<5(C05Q&P``3(GRO@(```!02(T-6!L``$R)[S'`Z$S0
M__],B>^^P`$``.B_T/__7T%8@_C_=1+H<L___T2+"$&#^1$/A1L#``!(C84P
M____3(GO2(G&2(F%F/[__^BLS___B<.%P'1^2(N%J/[__TV)Z+X"````2(T5
ML!L``$B+"$B+!5YY``!(BS@QP.A,S?__13'D9@\?A```````2(M%R&1(*P0E
M*`````^%H00``$B-9=A,B>!;05Q!74%>05]=PP\?`$R)YTF#Q0CH[,[__TF)
MQ$B%P`^$M_[__^GC_O__#Q\`BX5(____)0#P```]`$````^%;/___T2+I4S_
M___H%L___T$YQ`^%5____XN%2/___R7_`0``/<`!```/A4'___],B??H_\S_
M_TR)_DB-/0<:``!)B<0QP.@+Z?__2(7`#X2"`@``2(N-J/[__TB)QDB+.>B@
M\/__2(F%H/[__TB%P`^$8`(``$B+O:#^___H9,W__TB)PH/X`WY,2(N-H/[_
M_TB82(TU[!D``$B)E9#^__](C7P!_.A+SO__A<!U)TB+E9#^__^#^@0/A#D#
M``!(BXV@_O__C4+[2)B`/`$O#X0C`P``D$R)_DR-/=48```QP$R)_^ALZ/__
M2(7`#X0#`@``#[8`A,`/A/@!```\,`^$\`$``$R)_TB--1(9```QP.A/[/__
M3(T]K!D``.B#S/__05=,B?)-B>A03(T-0Q@``+X"````3(GG2(T-:!D``#'`
MZ"W.__]86NM*9@\?A```````Z%O-__^#.!%U2>A!S/__@\,!2(/L"$V)Z$%7
M3(T-_A<``$R)\DR)YU-(C0TR&0``O@(```!0,<#HX\W__TB#Q""^P`$``$R)
MY^A2SO__@_C_=*U,B>_H)<S__TR)YDB-/:,7```QP.BDZ___3(GGZ/SY___I
MU_W__P\?@`````!%,>3I\/S__P\?A```````2(V=P/[__V8/'X0``````$B+
M.TB%_W0D3(G^,<#H3N?__TB)QTB%P'0%@#@`=4%(BWL(2(/#"$B%_W7<OPT`
M``"[#0```$R--1H8``!!O0T```#H^,K__T&X4P```$B)A:#^__])B<3ID_O_
M_P\?`.AKS/__2(/#"$B%P'2228G&Z4W[__](BX6H_O__38GHO@(```!(C15T
M&```2(L(2(L%8G8``$B+.#'`Z%#*___I__S__P\?`$B)Q^@@^?__2(M%R&1(
M*P0E*`````^%H0$``$B-9=A(B=];05Q!74%>05]=Z??+__\/'X``````2(N%
MJ/[__TB+`$B)A:#^___IBOW__V8N#Q^$``````!(B[V@_O__,?8QP.A@R___
MB<>%P`^$]OW__XF%J/[__^@[]___2(7`#XCB_?__B[VH_O__,=)(C7#V2(F%
MH/[__^@:S/__B[VH_O__N@8```!(C;6Z_O__Z,/)__^+O:C^__](BXV@_O__
M2(/X!@^%]0```(&]NO[__P!#04,/A8S]__]F@;V^_O__2$4/A7W]__\QTDB-
M<<Z)O:C^___HO,O__XN]J/[__[HH````2(N=F/[__TB)WNABR?__2(/X*`^%
MH0```$B-!047``"^`@```$V)Z$R)\L:%6/___P!(C0V]%@``3(T-D14``$R)
MYU`QP%/HA<O__UE>Z;']__](BX6H_O__2(M0"$B%T@^$ROS__TB)UTB)E:C^
M___HR\G__TB#^`,/AK'\__](BY6H_O__2(TU6!8``$B-?`+\Z+G*__](BY6H
M_O__A<!(#T65H/[__TB)E:#^___I?/S__^B'RO__2(T]*A8``#'`Z"GU__]F
M#Q^$``````#S#Q[Z54B-/1<5``!(B>5!54%43(UMU%-,B>Y(@^P89$B+'"4H
M````2(E=V$B+'2UT``!D3(LC00^VA"2P````08B$)+$````QP.B1Y/__2(7`
M=`F`.#$/A&L!```QP.CL[___9$R+(TR)Y[D#````N@$```!(C377%0``Z%_(
M__])B<1(A<!T*4B+0!!D2(L[2(T5O14``$B+,.APR/__28M$)!!(BS#V1@Y`
M#X5&`0``9$B+.[D#````N@$```!(C363%0``Z!3(__])B<1(A<!T,4B-/184
M``!,B>XQP.C[X___2(G"28M$)!!(BSA(A=(/A.<```!(B?YD2(L[Z`O(__]D
M2(L[N@$```!(C35'%0``Z";'__]D2(L[2(T53!4``$B)QNCCQ___9$B+`TR)
M[DB-/:T3``#&@+$`````,<#HE^/__TB)!8!S``!(B<-(A<!T0+[``0``2(G?
MZ!O*__^-4`&#^@%V"8/X$0^%D````$B+1=AD2"L$)2@````/A9H```!(@\08
M6T%<05U=PP\?0`!(BSTY<P``Z(SV__](B04E<P``2(G#2(7`=:5(C3U>%0``
M,<#H_\C__P\?@`````"`>`$`#X26_O__Z8;^__]F#Q^$``````!(BQ7Q<@``
M2(LRZ"'F___I$?___P\?0`!D2(L[Z%_(___IK/[__XG!2(L%R7(``$B)VDB-
M/2<5``!(BS`QP.B=R/__Z$C(__\/'X0``````/,/'OI52(GE05132(UUY$B)
M^TB-/?82``!(@^P09$B+!"4H````2(E%Z#'`Z'_B__](A<!T'`^V$(32#Y3`
M@/HP#Y3""-!U"DB%VW0%@#L`=1Y(BT7H9$@K!"4H````=7%(@\006T%<7<-F
M#Q]$``!(B=_H2.S__[XO````2(G'28G$Z"C'__](C5`!2(7`3`]%XDR)Y^B%
MQ___N@0```!(C34T$P``2(G'Z-'%__^%P'6?2(M%Z&1(*P0E*````'402(/$
M$$B)WUM!7%WI+N/__^AIQ___9@\?A```````\P\>^E6_@````$B)Y>B>Q?__
M9@]O!>91``!(QT`P``````\1`&8/;P7C40``QT!X``````\10!!F#V\%X%$`
M``\10"!=PV8N#Q^$``````#S#Q[Z54ACPDB)Y4%728G_059!54R-;SA!5$F)
MQ%-(@^PH2(EUR$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'02(E',$AC
M1WB%P`^%+0$``$&#_#\/CH0```!$B>-,BW7(P>L&C4/_2,'C!HE%Q$P!\TB)
M1;@/'X0``````/-!#V\&3(G_28/&0$$/$44`\T$/;T;000\111#S00]O1N!!
M#Q%%(/-!#V]&\$$/$44PZ'G*__]).=YUQ$B+1;A(BTW(1(MUQ$C!X`9(C40!
M0$'WWDB)1<A!P>8&1XUD-,!)8\1(@_@(<FY(BWW(28UW0$R)Z4B#YOA(BQ=(
M*?%)B5<X2(M4!_A(*<])B50%^$@!R$F)_4B#X/A(@_@(<B!(@^#X,=))BTP5
M`$B)#!9(@\((2#G"<NX/'X0``````$6)9WA(@\0H6T%<05U!7D%?7<,/'T0`
M`*@$=6Q(A<!TWTB+3<@/MA%!B%<XJ`)TT`^W5`'^9D&)5`7^Z\,/'P!!OD``
M``!(BW7(28U\!0!!*<9%.>9%#T_T26/>2(G:Z%S&__]!BT=X1`'P08E'>(/X
M0'603(G_2`%=R$4I].AMR?__Z8O^__](BTW(BQ%!B5<XBU0!_$&)5`7\Z6#_
M___S#Q[Z54B)Y4%73(U^.$%6055!5$F)_%-(B?-(@^P(3(MV*$R+;C!,B?!(
MP>@#@^`_C4@!QD0&.(!(8\%,`?B#^3@/CJ@!``"Z0````"G*=`\QR8G.@\$!
MQ@0P`#G1<O-(B=_HZ,C__V8/[\`/$4,X2<=',`````!!#Q%'$$$/$4<@3(GJ
M00^VQDV)\$R)]TC!ZAA(P>`(3(GI2<'H$$F)T4R)\DC![Q@/MO9,B>I(P>D0
M2`GP00^V\`^VR4C!X`A("?!`#[;W2(G?2,'@"$@)\$$/MO5(P>`(2`GP#[;V
M00^VT4C!X`A("?!(P>`(2`G(2,'@"$@)T$B)0W#H3\C__TB+`TR)YTR)X4R)
MXDC!Z!A!B`0D2(L#2,'H$$&(1"0!2(L#B&<"2(L#08A$)`-(BT,(2,'H&$&(
M1"0$2(M#"$C!Z!!!B$0D!4B+0PB(9P9(BT,(08A$)`=(BT,02,'H&$&(1"0(
M2(M#$$C!Z!!!B$0D"4B+0Q"(80I(BT,008A$)`M(BT,82,'H&$&(1"0,2(M#
M&$C!Z!!!B$0D#4B+0QB(9PY(BT,82(G?08A$)`](BT,@2,'H&$&(1"002(M#
M($C!Z!!!B$0D$4B+0R"(8A)(BT,@08A$)!-(@\0(6T%<05U!7D%?7>DSPO__
M#Q\`NC@````Q]BG*@_H(<RKVP@1U;872#X1W_O__Q@``]L("#X1K_O__,<EF
MB4P0_NE?_O__#Q]$``")T4C'``````!(QT0(^`````!(C4@(2(/A^$@IR`'"
M@^+X@_H(#X(O_O__@^+X,<")QX/`"$B)-#DYT'+SZ1C^__]F#Q]$``#'````
M``#'1!#\`````.G__?__9BX/'X0```````\?`/,/'OI(BPV];```Z;#`___S
M#Q[Z2(/L"$B#Q`C#````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15(`55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R
M="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,P`M
M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M``````$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````
M``````````$;`SL$`0``'P```'!O__\X`0``X'+__V`!``#P<O__>`$``%!V
M__\`!0``8'C__R`!``!0>?__D`$``*"/___``0``<)#__^P!``#PD/__$`(`
M`'"2__\\`@``T)+__UP"``"PD___B`(``#"6__^X`@``8);__\P"``!`E___
M]`(``%"7__\(`P``<)G__S0#``"PF?__5`,``!";__^$`P``<)___[0#``#@
MG___V`,``*"@___T`P``\*'__QP$```0HO__/`0``/"B__]L!```P*K__Z0$
M``#PK/__T`0``-"M__\H!0``(*[__T@%````L/__>`4``)"R__^H!0``````
M`!0``````````7I2``%X$`$;#`<(D`$``!0````<````.'?__R8`````1`<0
M`````"0````T````,&[__W`#````#A!&#AA*#PMW"(``/QHY*C,D(@`````4
M````7````'AQ__\0```````````````4````=````'!Q__]@`P``````````
M```L````C````+AW__]+%@```$$.$(8"0PT&7H\#C@2-!8P&@P<#(Q8*#`<(
M00L````H````O````-B-___+`````$$.$(8"0PT&38\#C@2-!8P&@P<"=@H,
M!PA)"R````#H````?([__WP`````00X0A@)##09/@P,"8PH,!PA!"R@````,
M`0``V([__W0!````00X0A@)##090CP..!(T%C`:#!P)`"@P'"$0+'````#@!
M```LD/__6P````!%#A"&`E$-!D6#`W@,!P@H````6`$``&R0___8`````$$.
M$(8"0PT&5XX#C02,!8,&`GP*#`<(00L``"P```"$`0``()'__W$"````00X0
MA@)%#09)CP..!(T%C`:#!P-$`0H,!PA%"P```!````"T`0``<)/__RD`````
M````)````,@!``",D___W0````!%#A"&`D,-!F&-`XP$@P4"K@H,!PA!"Q``
M``#P`0``1)3__PD`````````*`````0"``!`E/__$@(```!%#A"&`D,-!ER/
M`XX$C06,!H,'`G(*#`<(2@L<````,`(``#26__\R`````$4.$(8"2`T&08,#
M7PP'""P```!0`@``5);__U$!````10X0A@)##093C`.#!`+O"@P'"$8+80H,
M!PA/"P```"P```"``@``A)?__UL$````10X0A@)##09(CP..!(T%C`9,@P<#
M$`0*#`<(10L``"````"P`@``M)O__VD`````10X0A@)*#08"1PH,!PA*"P``
M`!@```#4`@```)S__\``````10X0A@)##08````D````\`(``*2<__]&`0``
M`$$.$(8"0PT&8HT#C`2#!0+="@P'"$4+'````!@#``#,G?__'@````!%#A"&
M`D,-!E4,!P@````L````.`,``,R=___>`````$4.$(8"0PT&2H\#C@2-!4F,
M!DN#!P)*"@P'"$@+```T````:`,``'R>___'!P```$4.$(8"0PT&1(\#C@16
MC06,!H,'`P(#"@P'"$0+`_P""@P'"$P+`"@```"@`P``%*;__R@"````10X0
MA@)*#09$C0.,!$R#!0-T`0H,!PA%"P``+````,P#```8J/__UP````!%#A"&
M`D,-!D>,`X,$`EH*#`<(1PL"70H,!PA%"P``)````/P#``!(<?__#@(```!%
M#A"&`D,-!D>,`X,$`VH!"@P'"$$+`!P````D!```H*C__T8`````10X0A@)(
M#09X#`<(````+````$0$``#0J/__X`$```!%#A"&`D8-!D*/`T>.!(T%1HP&
M2(,'`S`!"@P'"$8++````'0$``"`JO__@P(```!%#A"&`D,-!D*/`TJ.!(T%
MC`9$@P<#T`$*#`<(2`L`$````*0$``#@K/__$```````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/`I````````L"D```````!.<0``
M`````.EP````````!G$```````!?<0````````$`````````Z`(````````!
M`````````/@"````````#```````````(`````````T`````````4&,`````
M```9`````````*C+````````&P`````````(`````````!H`````````L,L`
M```````<``````````@`````````]?[_;P````"8!`````````4`````````
M2`X````````&`````````'@%````````"@````````"!!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````$`4````````4``````````<`````````%P````````#H%0``````
M``<`````````"!0````````(`````````.`!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````"(
M$P```````/___V\``````0````````#P__]O`````,H2````````^?__;P``
M```(````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MV,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*%5B=6YT=2`Q-"XR+C`M-W5B=6YT=3$I(#$T+C(N,```
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92YP86-K86=E`"YN;W1E+D%"22UT86<`+F=N=2YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N
M7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N<&QT+F=O=``N<&QT+G-E
M8P`N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE
M`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD871A+G)E;"YR;P`N9'EN86UI
M8P`N9&%T80`N8G-S`"YC;VUM96YT````````````````````````````````
M````````````````````````````````````````````````````````````
M```+`````0````(`````````&`,````````8`P```````!P`````````````
M```````!````````````````````$P````<````"`````````#@#````````
M.`,````````P````````````````````"````````````````````"8````'
M`````@````````!H`P```````&@#````````)`````````````````````0`
M```````````````````Y````!P````(`````````C`,```````",`P``````
M`.P````````````````````$````````````````````1P````<````"````
M`````'@$````````>`0````````@````````````````````!```````````
M`````````%4```#V__]O`@````````"8!````````)@$````````X```````
M```'``````````@```````````````````!?````"P````(`````````>`4`
M``````!X!0```````-`(````````"`````$````(`````````!@`````````
M9P````,````"`````````$@.````````2`X```````"!!```````````````
M`````0```````````````````&\```#___]O`@````````#*$@```````,H2
M````````O``````````'``````````(``````````@````````!\````_O__
M;P(`````````B!,```````"($P```````(``````````"`````$````(````
M````````````````BP````0````"``````````@4````````"!0```````#@
M`0````````<`````````"``````````8`````````)4````$````0@``````
M``#H%0```````.@5````````$`4````````'````&@````@`````````&```
M``````"?`````0````8``````````"``````````(````````!L`````````
M```````````$````````````````````F@````$````&`````````"`@````
M````("````````!P`P``````````````````$``````````0`````````*4`
M```!````!@````````"0(P```````)`C````````$```````````````````
M`!``````````$`````````"N`````0````8`````````H",```````"@(P``
M`````&`#```````````````````0`````````!``````````MP````$````&
M```````````G`````````"<```````!0/```````````````````(```````
M`````````````+T````!````!@````````!08P```````%!C````````#0``
M``````````````````0```````````````````##`````0````(`````````
M`'``````````<````````+!````````````````````0````````````````
M````RP````$````"`````````+"P````````L+`````````$`0``````````
M````````!````````````````````-D````!`````@````````"XL0``````
M`+BQ````````N`0```````````````````@```````````````````#C````
M#@````,`````````J,L```````"HNP````````@````````````````````(
M``````````@`````````[P````\````#`````````+#+````````L+L`````
M```(````````````````````"``````````(`````````/L````!`````P``
M``````"XRP```````+B[````````(`````````````````````@`````````
M```````````(`0``!@````,`````````V,L```````#8NP`````````"````
M````"``````````(`````````!``````````J0````$````#`````````-C-
M````````V+T````````H`@``````````````````"``````````(````````
M`!$!```!`````P``````````T`````````#`````````*```````````````
M``````@````````````````````7`0``"`````,`````````*-`````````H
MP````````"@````````````````````(````````````````````'`$```$`
M```P````````````````````*,`````````E`````````````````````0``
M```````!``````````$````#`````````````````````````$W`````````
@)0$```````````````````$`````````````````````
